@@ -102,7 +102,7 @@ class BaseApp:
         # Options
         parser.add_argument(
             "--authenticator",
-            help="Authenticator: snowflake, externalbrowser, oauth, oauth_snowpark (default: SNOWFLAKE_AUTHENTICATOR env variable)",
+            help="Authenticator: snowflake, externalbrowser, oauth, oauth_snowpark, workload_identity (default: SNOWFLAKE_AUTHENTICATOR env variable)",
             default=environ.get("SNOWFLAKE_AUTHENTICATOR", "snowflake"),
         )
         parser.add_argument(
@@ -110,6 +110,16 @@ class BaseApp:
             help="Oauth access token (default: SNOWFLAKE_OAUTH_TOKEN env variable)",
             default=environ.get("SNOWFLAKE_OAUTH_TOKEN"),
         )
+        parser.add_argument(
+            "--workload-identity-token",
+            help="Workload identity token (default: SNOWFLAKE_WORKLOAD_IDENTITY_TOKEN env variable)",
+            default=environ.get("SNOWFLAKE_WORKLOAD_IDENTITY_TOKEN"),
+        )
+        parser.add_argument(
+            "--workload-identity-provider",
+            help="Workload identity provider (default: SNOWFLAKE_WORKLOAD_IDENTITY_PROVIDER env variable)",
+            default=environ.get("SNOWFLAKE_WORKLOAD_IDENTITY_PROVIDER"),
+        )
         parser.add_argument(
             "--passphrase",
             help="Passphrase for private key file (default: SNOWFLAKE_PRIVATE_KEY_PASSPHRASE env variable)",
@@ -241,6 +251,9 @@ class BaseApp:
         parser.add_argument(
             "--refresh-user-passwords", help="Additionally refresh passwords of users", default=False, action="store_true"
         )
+        parser.add_argument(
+            "--refresh-workload-identity", help="Additionally refresh workload identites of users", default=False, action="store_true"
+        )
         parser.add_argument(
             "--refresh-future-grants",
             help="Additionally refresh missing grants for existing objects derived from future grants",
@@ -312,6 +325,9 @@ class BaseApp:
         elif args["authenticator"] == "oauth_snowpark":
             if not args["a"]:
                 return False
+        elif args["authenticator"] == "workload_identity":
+            if not args["a"] or not args["workload_identity_token"] or not args["workload_identity_provider"]:
+                return False
         elif args["authenticator"] is not None:
             return False
 
@@ -491,6 +507,9 @@ class BaseApp:
         if self.args.get("refresh_user_passwords"):
             settings.refresh_user_passwords = True
 
+        if self.args.get("refresh_workload_identity"):
+            settings.refresh_workload_identity = True
+
         if self.args.get("refresh_future_grants"):
             settings.refresh_future_grants = True
 
@@ -603,8 +622,13 @@ class BaseApp:
             else:
                 raise ValueError("Failed to obtain host for 'oauth_snowpark' authenticator")
 
+        elif self.args.get("authenticator") == "workload_identity":
+            options["authenticator"] = "workload_identity"
+            options["workload_identity_provider"] = self.args["workload_identity_provider"]
+            options["token"] = self.args["workload_identity_token"]
+
         else:
-            raise ValueError("Only 'snowflake', 'externalbrowser', 'oauth' and 'oauth_snowpark' authenticators are supported")
+            raise ValueError("Only 'snowflake', 'externalbrowser', 'oauth', 'oauth_snowpark' and 'workload_identity' authenticators are supported")
 
         if self.args.get("query_tag"):
             options["session_parameters"] = {
